import store from '@/store';
import { getToken } from '@/utils/auth';
import axios from 'axios';
import { Message } from 'element-ui';

axios.defaults.withCredentials = true; // 跨域请求时是否需要使用凭证
axios.defaults.dataType = 'json';
axios.defaults.headers['cache-control'] = 'no-cache';
axios.defaults.headers['Content-Type'] = 'application/json';
axios.defaults.headers['X-Requested-With'] = 'XMLHttpRequest';

const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  // withCredentials: true, // 跨域请求时发送 cookies
  timeout: 5000
});

// 请求拦截器
service.interceptors.request.use(
  config => {
    if (store.getters.token) {
      config.headers['X-Token'] = getToken();
    }
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);

//响应拦截器
service.interceptors.response.use(
  response => {
    const res = response.data;

    if (res.code === 404) {
      Message({
        message: '请求的资源不存在',
        type: 'error',
        duration: 3 * 1000
      });
      return Promise.reject(new Error(res.message || 'Error'));
    }

    // 返回数据失败
    if (res.Status === 0) {
      Message({
        message: res.Error,
        type: 'error',
        duration: 3 * 1000
      });
      return Promise.reject(new Error(res.Error || 'Error'));
    }
    return res;
  },
  error => {
    Message({
      message: error.message,
      type: 'error',
      duration: 3 * 1000
    });
    return Promise.reject(error);
  }
);

export default service;
